summaryrefslogtreecommitdiffstats
path: root/qt/SciListBox.h
diff options
context:
space:
mode:
Diffstat (limited to 'qt/SciListBox.h')
-rw-r--r--qt/SciListBox.h19
1 files changed, 10 insertions, 9 deletions
diff --git a/qt/SciListBox.h b/qt/SciListBox.h
index 2bbcf7d..5541dea 100644
--- a/qt/SciListBox.h
+++ b/qt/SciListBox.h
@@ -1,23 +1,23 @@
// This sub-class of QListBox is needed to provide slots from which we can call
// ListBox's double-click callback. (And you thought this was a C++ program.)
//
// Copyright (c) 2006
// Riverbank Computing Limited <info@riverbankcomputing.co.uk>
//
-// This file is part of QScintilla.
+// This file is part of TQScintilla.
//
-// This copy of QScintilla is free software; you can redistribute it and/or
+// This copy of TQScintilla is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2, or (at your option) any
// later version.
//
-// QScintilla is supplied in the hope that it will be useful, but WITHOUT ANY
+// TQScintilla is supplied in the hope that it will be useful, but WITHOUT ANY
// WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
// FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
// details.
//
// You should have received a copy of the GNU General Public License along with
-// QScintilla; see the file LICENSE. If not, write to the Free Software
+// TQScintilla; see the file LICENSE. If not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
@@ -25,7 +25,7 @@
#define SCILISTBOX_H
-#include <qlistbox.h>
+#include <tqlistbox.h>
#include "Platform.h"
@@ -33,16 +33,17 @@
class ListBoxX;
-class SciListBox : public QListBox
+class SciListBox : public TQListBox
{
Q_OBJECT
+ TQ_OBJECT
public:
- SciListBox(QWidget *parent,ListBoxX *lbx_);
+ SciListBox(TQWidget *parent,ListBoxX *lbx_);
~SciListBox();
private slots:
- void handleDoubleClick(QListBoxItem *);
+ void handleDoubleClick(TQListBoxItem *);
private:
ListBoxX *lbx;
@@ -1,23 +1,23 @@
-// This sub-class of QListBox is needed to provide slots from which we can call
+// This sub-class of TQListBox is needed to provide slots from which we can call
// ListBox's double-click callback. (And you thought this was a C++ program.)
//